@@ -2,9 +2,11 @@ package chezmoi
 
 import (
 	"bytes"
+	"crypto/sha256"
 	"encoding/hex"
 	"fmt"
 	"io/fs"
+	"os/exec"
 	"runtime"
 	"time"
 )
@@ -25,7 +27,7 @@ type TargetStateEntry interface {
 // A TargetStateModifyDirWithCmd represents running a command that modifies
 // a directory.
 type TargetStateModifyDirWithCmd struct {
-	cmd           *lazyCommand
+	cmdFunc       func() *exec.Cmd
 	forceRefresh  bool
 	refreshPeriod Duration
 	sourceAttr    SourceAttr
@@ -39,11 +41,12 @@ type TargetStateDir struct {
 
 // A TargetStateFile represents the state of a file in the target state.
 type TargetStateFile struct {
-	*lazyContents
-	empty      bool
-	overwrite  bool
-	perm       fs.FileMode
-	sourceAttr SourceAttr
+	contentsFunc       func() ([]byte, error)
+	contentsSHA256Func func() ([32]byte, error)
+	empty              bool
+	overwrite          bool
+	perm               fs.FileMode
+	sourceAttr         SourceAttr
 }
 
 // A TargetStateRemove represents the absence of an entry in the target state.
@@ -51,18 +54,19 @@ type TargetStateRemove struct{}
 
 // A TargetStateScript represents the state of a script.
 type TargetStateScript struct {
-	*lazyContents
-	name          RelPath
-	interpreter   *Interpreter
-	condition     ScriptCondition
-	sourceAttr    SourceAttr
-	sourceRelPath SourceRelPath
+	name               RelPath
+	contentsFunc       func() ([]byte, error)
+	contentsSHA256Func func() ([32]byte, error)
+	interpreter        *Interpreter
+	condition          ScriptCondition
+	sourceAttr         SourceAttr
+	sourceRelPath      SourceRelPath
 }
 
 // A TargetStateSymlink represents the state of a symlink in the target state.
 type TargetStateSymlink struct {
-	*lazyLinkname
-	sourceAttr SourceAttr
+	linknameFunc func() (string, error)
+	sourceAttr   SourceAttr
 }
 
 // A modifyDirWithCmdState records the state of a directory modified by a
@@ -91,7 +95,7 @@ func (t *TargetStateModifyDirWithCmd) Apply(
 	}
 
 	runAt := time.Now().UTC()
-	if err := system.RunCmd(t.cmd.Command()); err != nil {
+	if err := system.RunCmd(t.cmdFunc()); err != nil {
 		return false, fmt.Errorf("%s: %w", actualStateEntry.Path(), err)
 	}
 
@@ -209,15 +213,16 @@ func (t *TargetStateFile) Apply(
 		// Compare file contents using only their SHA256 sums. This is so that
 		// we can compare last-written states without storing the full contents
 		// of each file written.
-		actualContentsSHA256, err := actualStateFile.ContentsSHA256()
+		actualContents, err := actualStateFile.Contents()
 		if err != nil {
 			return false, err
 		}
+		actualContentsSHA256 := sha256.Sum256(actualContents)
 		contentsSHA256, err := t.ContentsSHA256()
 		if err != nil {
 			return false, err
 		}
-		if bytes.Equal(actualContentsSHA256, contentsSHA256) {
+		if actualContentsSHA256 == contentsSHA256 {
 			if runtime.GOOS == "windows" || actualStateFile.perm == t.perm {
 				return false, nil
 			}
@@ -229,6 +234,16 @@ func (t *TargetStateFile) Apply(
 	return true, system.WriteFile(actualStateEntry.Path(), contents, t.perm)
 }
 
+// Contents returns t's contents.
+func (t *TargetStateFile) Contents() ([]byte, error) {
+	return t.contentsFunc()
+}
+
+// ContentsSHA256 returns the SHA256 sum of t's contents.
+func (t *TargetStateFile) ContentsSHA256() ([32]byte, error) {
+	return t.contentsSHA256Func()
+}
+
 // EntryState returns t's entry state.
 func (t *TargetStateFile) EntryState(umask fs.FileMode) (*EntryState, error) {
 	contents, err := t.Contents()
@@ -247,7 +262,7 @@ func (t *TargetStateFile) EntryState(umask fs.FileMode) (*EntryState, error) {
 	return &EntryState{
 		Type:           EntryStateTypeFile,
 		Mode:           t.perm &^ umask,
-		ContentsSHA256: HexBytes(contentsSHA256),
+		ContentsSHA256: HexBytes(contentsSHA256[:]),
 		contents:       contents,
 		overwrite:      t.overwrite,
 	}, nil
@@ -255,8 +270,13 @@ func (t *TargetStateFile) EntryState(umask fs.FileMode) (*EntryState, error) {
 
 // Evaluate evaluates t.
 func (t *TargetStateFile) Evaluate() error {
-	_, err := t.ContentsSHA256()
-	return err
+	if _, err := t.Contents(); err != nil {
+		return err
+	}
+	if _, err := t.ContentsSHA256(); err != nil {
+		return err
+	}
+	return nil
 }
 
 // Perm returns t's perm.
@@ -342,7 +362,7 @@ func (t *TargetStateScript) Apply(
 		}
 	}
 
-	scriptStateKey := []byte(hex.EncodeToString(contentsSHA256))
+	scriptStateKey := []byte(hex.EncodeToString(contentsSHA256[:]))
 	if err := PersistentStateSet(persistentState, ScriptStateBucket, scriptStateKey, &scriptState{
 		Name:  t.name,
 		RunAt: runAt,
@@ -353,7 +373,7 @@ func (t *TargetStateScript) Apply(
 	entryStateKey := actualStateEntry.Path().Bytes()
 	if err := PersistentStateSet(persistentState, EntryStateBucket, entryStateKey, &EntryState{
 		Type:           EntryStateTypeScript,
-		ContentsSHA256: HexBytes(contentsSHA256),
+		ContentsSHA256: HexBytes(contentsSHA256[:]),
 	}); err != nil {
 		return false, err
 	}
@@ -361,6 +381,16 @@ func (t *TargetStateScript) Apply(
 	return true, nil
 }
 
+// Contents returns t's contents.
+func (t *TargetStateScript) Contents() ([]byte, error) {
+	return t.contentsFunc()
+}
+
+// ContentsSHA256 returns the SHA256 sum of t's contents.
+func (t *TargetStateScript) ContentsSHA256() ([32]byte, error) {
+	return t.contentsSHA256Func()
+}
+
 // EntryState returns t's entry state.
 func (t *TargetStateScript) EntryState(umask fs.FileMode) (*EntryState, error) {
 	contentsSHA256, err := t.ContentsSHA256()
@@ -369,7 +399,7 @@ func (t *TargetStateScript) EntryState(umask fs.FileMode) (*EntryState, error) {
 	}
 	return &EntryState{
 		Type:           EntryStateTypeScript,
-		ContentsSHA256: HexBytes(contentsSHA256),
+		ContentsSHA256: HexBytes(contentsSHA256[:]),
 	}, nil
 }
 
@@ -395,7 +425,7 @@ func (t *TargetStateScript) SkipApply(persistentState PersistentState, targetAbs
 		if err != nil {
 			return false, err
 		}
-		scriptStateKey := []byte(hex.EncodeToString(contentsSHA256))
+		scriptStateKey := []byte(hex.EncodeToString(contentsSHA256[:]))
 		switch scriptState, err := persistentState.Get(ScriptStateBucket, scriptStateKey); {
 		case err != nil:
 			return false, err
@@ -416,7 +446,7 @@ func (t *TargetStateScript) SkipApply(persistentState PersistentState, targetAbs
 			if err != nil {
 				return false, err
 			}
-			if bytes.Equal(entryState.ContentsSHA256.Bytes(), contentsSHA256) {
+			if bytes.Equal(entryState.ContentsSHA256.Bytes(), contentsSHA256[:]) {
 				return true, nil
 			}
 		}
@@ -475,13 +505,10 @@ func (t *TargetStateSymlink) EntryState(umask fs.FileMode) (*EntryState, error)
 			Type: EntryStateTypeRemove,
 		}, nil
 	}
-	linknameSHA256, err := t.LinknameSHA256()
-	if err != nil {
-		return nil, err
-	}
+	linknameSHA256 := sha256.Sum256([]byte(linkname))
 	return &EntryState{
 		Type:           EntryStateTypeSymlink,
-		ContentsSHA256: linknameSHA256,
+		ContentsSHA256: linknameSHA256[:],
 		contents:       []byte(linkname),
 	}, nil
 }
@@ -492,6 +519,10 @@ func (t *TargetStateSymlink) Evaluate() error {
 	return err
 }
 
+func (t *TargetStateSymlink) Linkname() (string, error) {
+	return t.linknameFunc()
+}
+
 // SkipApply implements TargetStateEntry.SkipApply.
 func (t *TargetStateSymlink) SkipApply(persistentState PersistentState, targetAbsPath AbsPath) (bool, error) {
 	return false, nil
