@@ -17,8 +17,8 @@ import (
 	"github.com/tobischo/gokeepasslib/v3"
 	"github.com/twpayne/go-expect"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
-	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
+	"github.com/twpayne/chezmoi/internal/chezmoi"
+	"github.com/twpayne/chezmoi/internal/chezmoilog"
 )
 
 type keepassxcMode string
