@@ -6,7 +6,7 @@ import (
 	"github.com/spf13/cobra"
 	"github.com/twpayne/go-vfs/v5"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
+	"github.com/twpayne/chezmoi/internal/chezmoi"
 )
 
 type upgradeCmdConfig struct {
