@@ -24,8 +24,8 @@ import (
 	"github.com/google/go-github/v61/github"
 	"github.com/spf13/cobra"
 
-	"github.com/twpayne/chezmoi/v2/internal/chezmoi"
-	"github.com/twpayne/chezmoi/v2/internal/chezmoilog"
+	"github.com/twpayne/chezmoi/internal/chezmoi"
+	"github.com/twpayne/chezmoi/internal/chezmoilog"
 )
 
 const (
@@ -146,7 +146,7 @@ func (c *Config) runUpgradeCmd(cmd *cobra.Command, args []string) error {
 			return err
 		}
 	case upgradeMethodWinGetUpgrade:
-		if err := c.winGetUpgrade(); err != nil {
+		if err := c.winGetUpgrade(); err != nil { //nolint:nolintlint,staticcheck
 			return err
 		}
 	default:
